/**
 * JS of Codeeditor_XH.
 *
 * Copyright (c) 2011-2012 Christoph M. Becker (see license.txt)
 */
 

// utf-8-marker: äöüß


var CODEEDITOR = {

    instances: new Array(),

    current: null,

    unloadHandlerAdded: false,
    
    
    onFocus: function(editor) {
	CODEEDITOR.current = editor;
    },

    
    toggleFullscreen: function() {
	var ce = CODEEDITOR.current;
	var scroller = ce.getScrollerElement();
	var html = document.getElementsByTagName('html')[0];
	if (scroller.className.search(/fullscreen/) < 0) {
	    scroller.className += ' fullscreen';
	    html.style.oldOverflow = html.style.overflow;
	    html.style.overflow = 'hidden';
	} else {
	    scroller.className = scroller.className.replace(/fullscreen/, '');
	    html.style.overflow = html.style.oldOverflow;
	}
	ce.refresh();
    },
    
    
    getTextareasByClass: function(name) {
        var textareas = document.getElementsByTagName('textarea');
        var pattern = new RegExp('(^|\\s)' + name + '(\\s|$)');
        var res = new Array();
        for (var i = 0, j = 0; i < textareas.length; i++) {
            if (pattern.test(textareas[i].className)) {
                res[j++] = textareas[i];
            }
        }
        return res;
    },

    
    uniqueId: function() {
        var id = 'codeeditor';
        var i = 0;
        while (document.getElementById(id + i) !== null) {i++}
        return id + i;
    },

        
    instantiateByClasses: function(classes, config, addSave) {
        classes = classes.split('|');
        for (var i = 0; i < classes.length; i++) {
            var textareas = this.getTextareasByClass(classes[i]);
            for (var j = 0; j < textareas.length; j++) {
                if (!textareas[j].getAttribute('id')) {
                    textareas[j].setAttribute('id', this.uniqueId());
                }
                this.instantiate(textareas[j].getAttribute('id'), config, addSave);
            }
        }
    },

    
    instantiate: function(id, config, addSave) {
        var ta = document.getElementById(id);
	var h = ta.offsetHeight;
        var cm = CodeMirror.fromTextArea(ta, config);
	cm.getScrollerElement().style.height = h + 'px';
	cm.refresh();
	CODEEDITOR.instances.push(cm);
	ta.form.onsubmit = function() {return CODEEDITOR.onSave(cm)};
	this.addUnloadHandler();
	
	if (addSave) {
	    var wrapper = cm.getWrapperElement();
	    var save = document.createElement('input');
	    with (save) {
		setAttribute('type', 'submit');
		setAttribute('class', 'submit');
		setAttribute('value', CODEEDITOR.text.save);
		style.marginTop = '1em';
	    }
	    if (wrapper.nextSibling) {
		wrapper.parentNode.insertBefore(save, wrapper.nextSibling);
	    } else {
		wrapper.parentNode.appendChild(save);
	    }
	}
    },
    
    addUnloadHandler: function() {
	if (!CODEEDITOR.unloadHandlerAdded) {
	    if (window.addEventListener) {
		window.addEventListener('beforeunload', this.beforeUnload, false);
	    } else {
		window.attachEvent('onbeforeunload', this.beforeUnload);
	    }
	    CODEEDITOR.unloadHandlerAdded = true;
	}
    },
    
    
    beforeUnload: function(e) {
	for (var i = 0; i < CODEEDITOR.instances.length; i++) {
	    if (CODEEDITOR.instances[0].historySize().undo > 0) {
		return e.returnValue = CODEEDITOR.text.confirmLeave;
	    }
	}
    },
    
    
    onSave: function(editor) {
	if (editor.historySize().undo == 0) {
	    alert(CODEEDITOR.text.noChanges);
	    return false;
	} else {
	    if (window.addEventListener) {
		window.removeEventListener('beforeunload', this.beforeUnload, false);
	    } else {
		window.detachEvent('onbeforeunload', this.beforeUnload);
	    }
	    return true;
	}
    }
}
